FlakeReference

Struct FlakeReference 

pub struct FlakeReference { /* private fields */ }
An unresolved flake reference.

Obtain one via FlakeReference::parse, then pass it to LockedFlake::lock (or LockFlags::add_input_override).

Implementations

Source

impl FlakeReference

pub fn parse( context: &Arc<Context>, fetch_settings: &FetchersSettings, flake_settings: &FlakeSettings, parse_flags: &FlakeReferenceParseFlags, s: &str, ) -> Result<(Self, String)>

Parse a flake reference string into a FlakeReference.

Returns both the parsed reference and any fragment that followed a # in the input string. For references without a fragment the second element is an empty string.

Errors

Returns an error if the C API call fails or returns a null pointer.