pub struct FlakeReferenceParseFlags { /* private fields */ }Expand description
Flags that control how a flake reference string is parsed.
Create one with FlakeReferenceParseFlags::new then optionally call
set_base_directory before passing it to
FlakeReference::parse.
Implementations
Sourceimpl FlakeReferenceParseFlags
impl FlakeReferenceParseFlags
Sourcepub fn new(
context: &Arc<Context>,
flake_settings: &FlakeSettings,
) -> Result<Self>
pub fn new( context: &Arc<Context>, flake_settings: &FlakeSettings, ) -> Result<Self>
Create new parse flags with default values.
Errors
Returns an error if the underlying allocation fails.
Sourcepub fn set_base_directory(self, dir: &str) -> Result<Self>
pub fn set_base_directory(self, dir: &str) -> Result<Self>
Set the base directory used when resolving relative flake references.
Errors
Returns an error if the C API call fails.