FlakeSettings

Struct FlakeSettings 

pub struct FlakeSettings { /* private fields */ }
Configuration for the Nix flake subsystem.

This enables flake evaluation features in the Nix evaluator (such as builtins.getFlake). Obtain a FlakeSettings and pass it to EvalStateBuilder::with_flake_settings before building the EvalState.

Example

use std::sync::Arc;

use nix_bindings::{Context, EvalStateBuilder, Store, flake::FlakeSettings};

fn main() -> Result<(), Box<dyn std::error::Error>> {
  let ctx = Arc::new(Context::new()?);
  let store = Arc::new(Store::open(&ctx, None)?);
  let flake_settings = FlakeSettings::new(&ctx)?;
  let state = EvalStateBuilder::new(&store)?
    .with_flake_settings(&flake_settings)?
    .build()?;

  Ok(())
}

Implementations

Source

impl FlakeSettings

pub fn new(context: &Arc<Context>) -> Result<Self>

Create a new set of flake settings with default values.

Errors

Returns an error if the underlying allocation fails.